#ifndef KLABEL_H
#define KLABEL_H

#include <QLabel>
#include "gui_g.h"

namespace kdk {

/**
 * @defgroup Label Module
 */

enum KLabelType{
    NormalType,
    DataType
};

class KLabelPrivate;

/**
 * @brief 继承qlabel
 * @since 2.4
 */
class GUI_EXPORT KLabel :public QLabel
{
    Q_OBJECT
public:
    KLabel(QWidget *parent = nullptr);

    /**
     * @brief 设置label类型，NormalType和IconAndTextType
     * @param type
     */
    void setLabelType(KLabelType type = KLabelType::DataType);

    /**
     * @brief 设置是否启用文本/图标高亮色
     * @param flag
     */
    void setDataHightColor(bool flag);

    /**
     * @brief 设置图标pixmap
     * @param pixmap
     */
    void setPixmap(const QPixmap &pixmap);

    /**
     * @brief 获取图标
     * @return
     */
    const QPixmap *	pixmap() const;

    /**
     * @brief 设置背景颜色
     * @param flag
     */
    void setBackgroundColor(bool flag,QColor color = Qt::white );

    /**
     * @brief 设置圆角
     * @param bottomLeft
     * @param topLeft
     * @param topRight
     * @param bottomRight
     */
    void setBorderRadius(int bottomLeft,int topLeft,int topRight,int bottomRight);

    /**
     * @brief 设置圆角
     * @param radius
     */
    void setBorderRadius(int radius);

protected:
    void paintEvent(QPaintEvent* event);
    QSize sizeHint() const;
    void resizeEvent(QResizeEvent *event);

private:
    Q_DECLARE_PRIVATE(KLabel)
    KLabelPrivate* const d_ptr;

};

}
#endif // KLABEL_H
