#ifndef KPROGRESSBAR_H
#define KPROGRESSBAR_H

#include "gui_g.h"
#include <QProgressBar>

namespace kdk
{

/** @defgroup BarModule
  * @{
  */

/**
 * @brief 支持三种状态
 */
enum ProgressBarState
{
    NormalProgress,
    FailedProgress,
    SuccessProgress
};
class KProgressBarPrivate;

/**
 * @brief 进度条，支持三种状态显示
 */
class GUI_EXPORT KProgressBar:public QProgressBar
{
    Q_OBJECT

public:
    KProgressBar(QWidget*parent);

    /**
     * @brief 获取状态
     * @return
     */
    ProgressBarState state();

    /**
     * @brief 设置状态
     * @param state
     */
    void setState(ProgressBarState state);

    /**
     * @brief 获取文本
     * @return
     */
    QString text() const override;

    /**
     * @brief 设置方向
     */
    void setOrientation(Qt::Orientation);

    /**
     * @brief 设置进度条宽度
     * @param width
     * @since 1.2
     */
    void setBodyWidth(int width);

protected:
    void paintEvent(QPaintEvent *event) override;
    QSize sizeHint() const;

private:
    Q_DECLARE_PRIVATE(KProgressBar)
    KProgressBarPrivate* const d_ptr;
};
}
/**
  * @example testprogressbar/widget.h
  * @example testprogressbar/widget.cpp
  * @}
  */
#endif // KPROGRESSBAR_H
