#ifndef KTABBAR_H
#define KTABBAR_H

#include "gui_g.h"
#include <QTabBar>
#include <QIcon>

namespace kdk
{

/** @defgroup BarModule
  * @{
  */

/**
 * @brief 支持三种样式
 */
enum KTabBarStyle
{
    SegmentDark,
    SegmentLight,
    Sliding
};

class KTabBarPrivate;

/**
 * @brief 支持三种样式
 */
class GUI_EXPORT KTabBar: public QTabBar
{
    Q_OBJECT

public:
    KTabBar(KTabBarStyle barStyle = SegmentLight,QWidget* parent = nullptr);
    ~KTabBar();

    /**
     * @brief 设置TabBar样式
     * @param barStyle
     */
    void setTabBarStyle(KTabBarStyle barStyle);

    /**
     * @brief 返回TabBar样式
     * @return
     */
    KTabBarStyle barStyle();

    /**
     * @brief 设置圆角半径，只对SegmentDark，SegmentLight样式生效
     * @param radius
     */
    void setBorderRadius(int radius);

    /**
     * @brief 获取圆角半径
     * @return
     */
    int borderRadius();

    /**
     * @brief 设置背景色
     * @param color
     * @since 1.2
     */
    void setBackgroundColor(const QColor& color);
Q_SIGNALS:
    /**
     * @brief 鼠标右键信号
     * @param point
     * @since 2.4
     */
    void rightlicked(QPoint point);
protected:
    QSize sizeHint() const;
    QSize minimumTabSizeHint(int index) const;
     QSize tabSizeHint(int index) const;
    void paintEvent(QPaintEvent *event);

private:
    Q_DECLARE_PRIVATE(KTabBar)
    KTabBarPrivate*const d_ptr;
};
}
/**
  * @example testtabbar/widget.h
  * @example testtabbar/widget.cpp
  * @}
  */
#endif //KTABBAR_H
