#ifndef KTAG_H
#define KTAG_H

#include "gui_g.h"
#include <QPushButton>

namespace kdk
{
/**
 * @defgroup TagModule
 */
class KTagPrivate;

/**
 * @brief 支持四种风格的tag
 */
enum TagStyle
{
    HighlightTag,
    BoderTag,
    BaseBoderTag,
    GrayTag,
    IconTag
};

/**
 * @brief 提供四种样式的标签，响应系统主题色变化
 */
class GUI_EXPORT KTag : public QPushButton
{
    Q_OBJECT

public:
    explicit KTag(QWidget *parent = nullptr);
    /**
     * @brief 设置关闭按钮是否可见
     */
    void setClosable(bool);
    /**
     * @brief 返回关闭按钮是否可见
     * @return bool
     */
    bool closable();
    /**
     * @brief 设置文本
     */
    void setText(const QString&);
    /**
     * @brief 获取当前文本
     * @return QString
     */
    QString text();

    /**
     * @brief 设置tag样式
     */
    void setTagStyle(TagStyle);
    /**
     * @brief 获取当前tag样式
     * @return TagStyle
     */
    TagStyle tagStyle();


    /**
     * @brief 设置背景颜色
     * @param flag
     * @since 2.4
     */
    void setBackgroundColor(QColor color);

    /**
     * @brief 设置半透明
     * @param flag
     * @since 2.4
     */
    void setTranslucent(bool flag);

    /**
     * @brief 获取是否启用半透明
     * @return bool
     * @since 2.4
     */
    bool translucent();

protected:
    void paintEvent(QPaintEvent* event);
    QSize sizeHint() const override;

private:
    Q_DECLARE_PRIVATE(KTag)
    KTagPrivate * const d_ptr;
};
}


#endif // KTAG_H
